@@ -1,7 +1,9 @@
 package Sah::Schema::unix::groupname;
 
-our $DATE = '2019-12-09'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-11'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.010'; # VERSION
 
 our $schema = [str => {
     summary => 'Unix group name',
@@ -36,7 +38,7 @@ Sah::Schema::unix::groupname - Unix group name
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::unix::groupname (from Perl distribution Sah-Schemas-Unix), released on 2019-12-09.
+This document describes version 0.010 of Sah::Schema::unix::groupname (from Perl distribution Sah-Schemas-Unix), released on 2020-02-11.
 
 =head1 DESCRIPTION
 
@@ -70,7 +72,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
