@@ -1,9 +1,9 @@
 package Sah::Schema::unix::local_groupname;
 
-# AUTHOR
-our $DATE = '2019-12-09'; # DATE
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-11'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our $schema = ['unix::groupname' => {
     summary => 'Unix group name that must exist on the system',
@@ -12,7 +12,7 @@ our $schema = ['unix::groupname' => {
 Support coercion from GID.
 
 _
-    'x.perl.coerce_rules' => ['From_int::convert_gid_to_unix_group', 'From_str::check_unix_group_exists'],
+    'prefilters' => ['Unix::convert_gid_to_unix_group', 'Unix::check_unix_group_exists'],
 }, {}];
 
 1;
@@ -30,7 +30,7 @@ Sah::Schema::unix::local_groupname - Unix group name that must exist on the syst
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::unix::local_groupname (from Perl distribution Sah-Schemas-Unix), released on 2019-12-09.
+This document describes version 0.010 of Sah::Schema::unix::local_groupname (from Perl distribution Sah-Schemas-Unix), released on 2020-02-11.
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
